@@ -1,4 +1,5 @@
 import json
+import logging
 
 from semantha_sdk.rest.rest_client import RestClient
 from semantha_sdk.api.semantha_api import SemanthaAPI
@@ -20,7 +21,7 @@ def login(server_url: str, key: str = None, key_file: str = None) -> SemanthaAPI
     """
     if(not server_url.endswith("/tt-platform-server")):
         server_url += "/tt-platform-server"
-    __s = None
+    __api = None
     if key:
         pass
     elif key_file:
@@ -29,9 +30,10 @@ def login(server_url: str, key: str = None, key_file: str = None) -> SemanthaAPI
     else:
         raise ValueError("You need to supply an API key to login, either directly or via a file.")
     
-    __s = SemanthaAPI(RestClient(server_url, key), f"/api/{__PLATFORM_SERVER_API_VERSION}", "/api")
+    __api = SemanthaAPI(RestClient(server_url, key), f"/api/{__PLATFORM_SERVER_API_VERSION}", "/api")
 
     # check whether API key is valid or not
-    __s.currentuser.get()
-
-    return __s
+    info = __api.info.get()
+    logger = logging.getLogger()
+    logger.info(f"Semantha API version: {info.version}")
+    return __api
