@@ -11,18 +11,18 @@ class DiffEndpoint(SemanthaAPIEndpoint):
     def _endpoint(self):
         return self._parent_endpoint + "/diff"
 
-    def post(self, left_text: str, right_text: str) -> list[DiffDTO]:
+    def post(self, left: str, right: str) -> list[DiffDTO]:
         """ Create a diff between two given texts.
 
         Args:
-            left_text (object): One of the two texts for the diff.
-            right_text (object): The other text for the diff.
+            left (object): One of the two texts for the diff.
+            right (object): The other text for the diff.
         """
 
         return self._session.post(
             url=self._endpoint,
             body={
-                "left": left_text,
-                "right": right_text
+                "left": left,
+                "right": right
             }
         ).execute().to(DiffSchema)
