@@ -14,12 +14,12 @@ class DomainSettingsEndpoint(SemanthaAPIEndpoint):
 
     def patch(
             self,
-            domain_settings: PatchDomainSettings
+            domainsettings: PatchDomainSettings
     ) -> DomainSettings:
         """Patch one or more domain setting(s)"""
         #TODO: add Args description
         response = self._session.patch(
             self._endpoint,
-            json=DomainSettingsSchema().dump(domain_settings)
+            json=DomainSettingsSchema().dump(domainsettings)
         ).execute()
         return response.to(DomainSettingsSchema)
