@@ -37,6 +37,13 @@ class DocumentCluster(SemanthaModelEntity):
 
 DocumentClusterSchema = class_schema(DocumentCluster, base_schema=SemanthaSchema)
 
+@dataclass(frozen=True)
+class ClusterDocumentsResponse(SemanthaModelEntity):
+    clusters: List[DocumentCluster]
+    plotly: dict
+
+ClusterDocumentsResponseSchema = class_schema(ClusterDocumentsResponse, base_schema=SemanthaSchema)
+
 
 @dataclass(frozen=True)
 class ParagraphCluster(SemanthaModelEntity):
