@@ -17,5 +17,8 @@ class Document(DocumentInformation):
     references: Optional[List[Reference]] = None
     image_pages: Optional[str] = None
 
+    def __hash__(self):
+        return hash(self.id)
+
 
 DocumentSchema = class_schema(Document, base_schema=SemanthaSchema)
