@@ -19,6 +19,8 @@ class DomainSettings(SemanthaModelEntity):
     enable_paragraph_end_detection: bool
     enable_paragraph_merging_based_on_formatting: bool
     enable_boost_word_filtering_for_input_documents: bool
+    enable_no_match_color_red: Optional[bool]
+    enable_saturated_match_colors: Optional[bool]
     tagging_similarity_mode: str
     enable_updating_fingerprints_on_tag_updates: bool
     similarity_matcher: str
