@@ -8,6 +8,7 @@ from marshmallow_dataclass import class_schema
 from semantha_sdk.model.named_entity import NamedEntity
 from semantha_sdk.model.reference import Reference
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
+from semantha_sdk.model.area import Area
 
 
 @dataclass(frozen=True)
@@ -17,6 +18,7 @@ class Sentence(SemanthaModelEntity):
     document_name: Optional[str]
     named_entities: Optional[List[NamedEntity]]
     references: Optional[List[Reference]]
+    areas: Optional[List[Area]]
 
 
 SentenceSchema = class_schema(Sentence, base_schema=SemanthaSchema)
