@@ -3,6 +3,7 @@ from __future__ import annotations
 import json
 from typing import Dict, Type
 
+from marshmallow import EXCLUDE
 from requests import Response
 from requests.structures import CaseInsensitiveDict
 
@@ -61,7 +62,10 @@ class SemanthaPlatformResponse:
         if as_dict is None and as_list is None:
             raise ValueError("response was neither and object or a list")
 
-        return schema.load(as_dict) if as_dict is not None else schema.load(as_list, many=True)
+        return schema.load(as_dict, unknown=EXCLUDE) if as_dict is not None else schema.load(as_list, many=True, unknown=EXCLUDE)
+
+    def as_bytes(self) -> bytes:
+        return self.__raw_response.content
 
     def __str__(self) -> str:
         return self.__raw_response.__str__()
@@ -76,7 +80,7 @@ def _check_and_translate_errors(response: Response) -> Response:
         elif response.status_code == 401:
             raise PermissionError(response.status_code, response.text)
         elif response.status_code == 404:
-            raise FileNotFoundError(response.status_code, response.text)
+            raise FileNotFoundError(response.status_code, response.text + " url: " + response.url)
         elif response.status_code == 405:
             raise NotImplementedError(response.status_code, response.text)
         elif response.status_code == 408:
