@@ -1,10 +1,38 @@
 from __future__ import annotations
 
+from io import FileIO, IOBase
+from typing import BinaryIO, Any
+
 from requests import Request
 
 from semantha_sdk.request.semantha_request import SemanthaRequest
 
 
+def _convert_value(value: Any):
+    if isinstance(value, IOBase):
+        return value
+
+    if isinstance(value, bool):
+        return str(value).lower()
+
+    return value
+
+
+def _filter_and_convert_to_str(data: dict, remove_empty_lists=False):
+    data = {k: v for k, v in data.items() if v is not None}
+
+    if remove_empty_lists:
+        data = {k: v for k, v in data.items() if not (isinstance(v, list) and len(v) == 0)}
+
+    data = {k: _convert_value(v) for k, v in data.items()}
+    return data
+
+
+def _filter_json(data: dict):
+    data = {k: v for k, v in data.items() if v is not None}
+    return data
+
+
 class RestClient:
 
     def __init__(self, server_url: str, api_key: str):
@@ -27,10 +55,26 @@ class RestClient:
                   auth=None,
                   cookies=None,
                   hooks=None,
-                  json=None
+                  json: dict | list = None
                   ) -> SemanthaRequest:
         if headers is None:
             headers = self.__build_headers_for_json_request()
+        else:
+            headers = {**headers, **self.__build_headers_for_json_request()}
+
+        if json is not None:
+            json = _filter_json(json)
+
+        if data is not None:
+            data = _filter_and_convert_to_str(data, remove_empty_lists=True)
+
+        if files is not None:
+            files = _filter_and_convert_to_str(files, remove_empty_lists=True)
+
+        if params is not None:
+            params = _filter_and_convert_to_str(params)
+
+        headers['User-Agent'] = 'semantha Python SDK; '
         request = Request(
             method=method,
             url=self.__server_url + url,
@@ -49,10 +93,17 @@ class RestClient:
     def get(self, url: str, q_params: dict[str, str] = None) -> SemanthaRequest:
         return self.__request("GET", url, params=q_params)
 
-    def post(self, url: str, body: dict = None, json: dict | list = None, q_params: dict[str, str] = None) -> SemanthaRequest:
+    def post(
+            self,
+            url: str,
+            body: dict = None,
+            json: dict | list = None,
+            q_params: dict = None,
+            headers: dict[str, str] = None,
+    ) -> SemanthaRequest:
         if body is None and json is None:
             raise ValueError("Either a body (files/form-data) or a json must be provided!")
-        return self.__request("POST", url, files=body, json=json, params=q_params)
+        return self.__request("POST", url, files=body, json=json, params=q_params, headers=headers)
 
     def delete(self, url: str, q_params: dict[str, str] = None, json: dict | list = None) -> SemanthaRequest:
         return self.__request("DELETE", url, params=q_params, json=json)
